******************
Command-line tools
******************

GBibClean
=========

.. argparse::
    :module: GooseBib.bibtex
    :func: _GbibClean_parser
    :prog: GBibClean

GbibDiscover
============

.. argparse::
    :module: GooseBib.bibtex
    :func: _GbibDiscover_parser
    :prog: GbibDiscover
